@@ -1,7 +1,3 @@
-from datetime import datetime, date
-import re
-import itertools
-from django.contrib.humanize.templatetags.humanize import intcomma
 from django.template import Library
 
 from ecl_tools.config.models import GlobalConfig
